import React from "react"
import { IGatsbyImageData } from "gatsby-plugin-image"

import Card from "./Card"

interface CardProps {
    title?: string
    content?: string
    image?: string | IGatsbyImageData
    to?: string
    anime?: boolean
    layout?: "top" | "left"
    className?: string
}

interface Props {
    cards?: CardProps[]
    layout?: "row" | "col" | "grid"
    className?: string
    anime?: boolean
}

const oCardProps = {
    row: {
        layout: "left",
        className: "",
    },
    col: {
        layout: "top",
        className: "",
    },
    grid: {
        layout: "top",
        className: "max-w-full",
    },
}

const CardList = (props: Props) => {
    const { cards = [], layout = "row", className = "", anime = true } = props

    const oListClassName = {
        row: `space-y-10 w-full ${className}`,
        col: `flex space-x-12 flex-nowrap justify-center ${className}`,
        grid: `grid grid-cols-1 md:grid-cols-2 xl:grid-cols-3 gap-12 ${className}`,
    }

    const tmpProps = oCardProps[layout]

    const listCards = cards.map((card, index) => {
        let cardProps = {
            ...card,
            ...tmpProps,
            anime,
        }

        return <Card key={index} {...(cardProps as CardProps)} />
    })

    return <div className={oListClassName[layout]}>{listCards}</div>
}

export default CardList
